import { 
  select, 
  csv, 
  scaleLinear, 
  scalePoint, 
  max,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 20, right:20, bottom:50, left: 170 };
  const title = 'Top 10 Most Populous Countries';
  const xAxisLabel = 'Population';
  const yAxisLabel = 'Population';
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  const xScale = scaleLinear()
    .domain([0,max(data, xValue)])
    .range([0, innerWidth])
    .nice();

  
  const yScale = scalePoint()
    .domain(data.map(yValue))
    .range([0,innerHeight])
    .padding(0.5);
  
  const xAxisTickFormat = number => 
    format('.3s')(number)
    .replace('G','B');
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth);
  
  const xAxis = axisBottom(xScale)
    .tickFormat(xAxisTickFormat)
    .tickSize(-innerHeight);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.right})`);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  g.append('text')
    .attr('class', 'title')
    .attr('y', -2)
    .attr('fill', 'black')
    .text(title);

  xAxisG.append('text')
    .attr('class','axis-label')
    .attr('y', 35)
    .attr('x', innerWidth / 2)
    .attr('fill', 'black')
    .text(xAxisLabel);
  
 
  g.selectAll('circle')
    .data(data)
  	  .enter()
        .append('circle')
  		.attr('cy', d => yScale(yValue(d)))
        .attr('cx', d => xScale(xValue(d)))
        .attr('r', 20);
  
};

csv('data.csv').then(data => {
    data.forEach(d => {
    d.population = +d.population * 1000;
  })
  render(data);
});
